@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021,2022 -- leonerd@leonerd.org.uk
 
-package Syntax::Operator::In 0.02;
+package Syntax::Operator::In 0.03;
 
 use v5.14;
 use warnings;
@@ -75,8 +75,9 @@ sub import_into
 Yields true if the value on the lefhand side is equal to any of the values in
 the list on the right, according to some equality test operator C<OP>.
 
-At present this test operator must be either C<eq> for string match, or C<==>
-for number match.
+This test operator must be either C<eq> for string match, or C<==> for number
+match, or any other custom infix operator that is registered in the
+C<XPI_CLS_EQUALITY> classification.
 
 =cut
 
@@ -104,14 +105,6 @@ Does the lacking of end marker make parsing harder though?
 
 =item *
 
-Use L<XS::Parse::Infix> support for defining new infix operators and permit
-cross-module integration with C<Syntax::Operator::Equ>:
-
-   $x in<===> @numbers-or-undef    # or  in:===
-   $x in<equ> @strings-or-undef    # or  in:equ
-
-=item *
-
 Consider cross-module integration with L<Syntax::Keyword::Match>, permitting
 
    match($val : elem) {
